# QUARK-plugin-ibm

### Provided Modules:

| Module               | Upstream Interface            | Downstream Interface |
|----------------------|-------------------------------|----------------------|
| circuit_to_estimator | quark.interface_types.circuit | None                 |
| circuit_to_sampler   | quark.interface_types.circuit | None                 |
